#include <Adafruit_NeoPixel.h>

#define BUTTON_PIN 2
#define PIXEL_PIN 1  // 根据实际连接更改引脚
#define PIXEL_COUNT 140

Adafruit_NeoPixel strip(PIXEL_COUNT, PIXEL_PIN, NEO_GRB + NEO_KHZ800);

boolean oldState = HIGH;
boolean animationActive = false;

void setup() {
  pinMode(BUTTON_PIN, INPUT_PULLUP);
  strip.begin();
  strip.setBrightness(50); // 设置亮度，避免太暗
  strip.show();
}

void loop() {
  boolean newState = digitalRead(BUTTON_PIN);

  // 检测按钮是否从高到低
  if (newState == LOW && oldState == HIGH) {
    delay(20); // 去抖动
    if (digitalRead(BUTTON_PIN) == LOW) {
      animationActive = !animationActive; // 切换动画状态
      if (!animationActive) {
        strip.clear();
        strip.show(); // 关闭灯效
      }
    }
  }
  oldState = newState;

  // 如果动画激活，运行闪烁效果
  if (animationActive) {
    fadeEffect(5, 60); // 调整步长和延迟控制效果
  }
}

void fadeEffect(int step, int delayTime) {
  for (int brightness = 0; brightness <= 255; brightness += step) {
    setAllPixels(strip.Color(brightness, brightness, brightness));
    strip.show();
    delay(delayTime);
  }

  for (int brightness = 255; brightness >= 0; brightness -= step) {
    setAllPixels(strip.Color(brightness, brightness, brightness));
    strip.show();
    delay(delayTime);
  }
}

void setAllPixels(uint32_t color) {
  for (int i = 0; i < strip.numPixels(); i++) {
    strip.setPixelColor(i, color);
  }
}
